pub enum PendingSessionHandshakeError {
Eth(EthStreamError),
Ecies(ECIESError),
Timeout,
UnsupportedExtraCapability,
}Expand description
Errors that can occur during handshaking/authenticating the underlying streams.
Variants
Eth(EthStreamError)
The pending session failed due to an error while establishing the eth stream
Ecies(ECIESError)
The pending session failed due to an error while establishing the ECIES stream
Timeout
Thrown when the authentication timed out
UnsupportedExtraCapability
Thrown when the remote lacks the required capability
Implementations
Sourceimpl PendingSessionHandshakeError
impl PendingSessionHandshakeError
Sourcepub const fn as_disconnected(&self) -> Option<DisconnectReason>
pub const fn as_disconnected(&self) -> Option<DisconnectReason>
Returns the DisconnectReason if the error is a disconnect message