pub struct Discovery { /* private fields */ }Expand description
An abstraction over the configured discovery protocol.
Listens for new discovered nodes and emits events for discovered nodes and their address.
Implementations
Sourceimpl Discovery
impl Discovery
Sourcepub async fn new(
tcp_addr: SocketAddr,
discovery_v4_addr: SocketAddr,
sk: SecretKey,
discv4_config: Option<Discv4Config>,
discv5_config: Option<Config>,
dns_discovery_config: Option<DnsDiscoveryConfig>,
nat: Option<NatResolver>,
) -> Result<Self, NetworkError>
pub async fn new( tcp_addr: SocketAddr, discovery_v4_addr: SocketAddr, sk: SecretKey, discv4_config: Option<Discv4Config>, discv5_config: Option<Config>, dns_discovery_config: Option<DnsDiscoveryConfig>, nat: Option<NatResolver>, ) -> Result<Self, NetworkError>
Spawns the discovery service.
This will spawn the [reth_discv4::Discv4Service] onto a new task and establish a listener
channel to receive all discovered nodes. When only discv5 is enabled, nat periodically
resolves its advertised external IP without waiting for peer votes. When ENR updates are
disabled or discv5 checks inbound connectivity, only explicit extip or extaddr settings
are applied.