pub struct TransactionsManagerConfig {
pub transaction_fetcher_config: TransactionFetcherConfig,
pub max_transactions_seen_by_peer_history: u32,
pub max_pending_pool_imports: usize,
pub propagation_mode: TransactionPropagationMode,
pub ingress_policy: TransactionIngressPolicy,
pub tx_channel_memory_limit_bytes: usize,
}Expand description
Configuration for managing transactions within the network.
Fields
transaction_fetcher_config: TransactionFetcherConfigConfiguration for fetching transactions.
max_transactions_seen_by_peer_history: u32Max number of seen transactions to store for each peer.
max_pending_pool_imports: usizeMax number of transactions allowed to be imported concurrently.
propagation_mode: TransactionPropagationModeHow new pending transactions are propagated.
ingress_policy: TransactionIngressPolicyWhich peers we accept incoming transactions or announcements from.
tx_channel_memory_limit_bytes: usizeMemory limit (in bytes) for the channel that carries
NetworkTransactionEvents from the NetworkManager to the TransactionsManager.
When the budget is exhausted, new events are dropped.